#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Python 2.3+ CSV Driver")
url = "http://www.python.org/"
doc = """
Description
-----------
Built-in python driver for CSV files.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP (Installer available)


Connection Properties
---------------------
* dbname            -- This is the file name of the CSV file (required)
* firstrowisheader  -- Does the first row contain header names? (optional)

Examples
--------
[demo]
comment = Exported CSV File
provider = csv
dbname = /path/to/my.csv
firstrowisheader = yes

Notes
-----
1. This driver has been partially tested.  If you are successfully using
   this driver, please let us know.
"""
